﻿using Newtonsoft.Json.Linq;
using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Net;
using System.Net.Http;
using System.Net.Http.Headers;
using System.Text;
using Silanis.ESL.SDK;
using Silanis.ESL.SDK.Builder;
using System.IO;

namespace Reminders
{
    class reminder
    {
        //replace api_key placeholder with your own value
        private static String apiUrl = "https://sandbox.e-signlive.com/api";
        private static String apiKey = "api_key";

        public static void Main(string[] args)
        {
            EslClient eslClient = new EslClient(apiKey, apiUrl);

            DocumentPackage package = PackageBuilder.NewPackageNamed("Reminder Example")
                        .WithSigner(SignerBuilder.NewSignerWithEmail("esl.signer1@example.com")
                                .WithFirstName("John")
                                .WithLastName("Smith")
                                .WithCustomId("client")
                                .SigningOrder(1))
                        .WithSigner(SignerBuilder.NewSignerWithEmail("esl.signer2@example.com")
                                .WithFirstName("Mary")
                                .WithLastName("Doe")
                                .WithCustomId("contractor")
                                .SigningOrder(2))
                        .WithDocument(DocumentBuilder.NewDocumentNamed("Cleaning Contract")
                                .FromFile("DOC_FILE_PATH")
                                .EnableExtraction())
                        .Build();

            PackageId packageId = eslClient.CreatePackage(package);

            //create reminder schedule
            ReminderSchedule reminderScheduleToCreate = ReminderScheduleBuilder.ForPackageWithId(packageId)
               .WithDaysUntilFirstReminder(2)
                   .WithDaysBetweenReminders(2)
                   .WithNumberOfRepetitions(10)
                   .Build();

            eslClient.ReminderService.CreateReminderScheduleForPackage(reminderScheduleToCreate);

            //retrive reminder schedule
            ReminderSchedule createdReminderSchedule = eslClient.ReminderService.GetReminderScheduleForPackage(packageId);

            //retrieve reminders sent to signers
            List<Reminder> reminders = createdReminderSchedule.Reminders;

            foreach (Reminder reminder in reminders)
            {
                Debug.WriteLine(reminder.SentDate);
            }

            //update reminder schedule
            ReminderSchedule reminderScheduleToUpdate = ReminderScheduleBuilder.ForPackageWithId(packageId)
                .WithDaysUntilFirstReminder(1)
                    .WithDaysBetweenReminders(1)
                    .WithNumberOfRepetitions(5)
                    .Build();

            eslClient.ReminderService.UpdateReminderScheduleForPackage(reminderScheduleToUpdate);
            ReminderSchedule updatedReminderSchedule = eslClient.ReminderService.GetReminderScheduleForPackage(packageId);

            //clear reminder schedule
            eslClient.ReminderService.ClearReminderScheduleForPackage(packageId);
            ReminderSchedule removedReminderSchedule = eslClient.ReminderService.GetReminderScheduleForPackage(packageId);
        }
    }
}
